@@ -1,6 +1,10 @@
 import asyncio
 import contextlib
 import logging
+import os
+import tarfile
+from pathlib import Path
+
 from typing import Union
 
 import discord
@@ -8,6 +12,7 @@ import lavalink
 
 from redbot.core import bank, commands
 from redbot.core.data_manager import cog_data_path
+from redbot.core.i18n import Translator
 from redbot.core.utils.chat_formatting import box, humanize_number
 from redbot.core.utils.menus import DEFAULT_CONTROLS, menu, start_adding_reactions
 from redbot.core.utils.predicates import MessagePredicate, ReactionPredicate
@@ -15,12 +20,14 @@ from redbot.core.utils.predicates import MessagePredicate, ReactionPredicate
 from ...audio_dataclasses import LocalPath
 from ...converters import ScopeParser
 from ...errors import MissingGuild, TooManyMatches
-from ...utils import CacheLevel, PlaylistScope
+from ...utils import CacheLevel, PlaylistScope, has_internal_server
 from ..abc import MixinMeta
-from ..cog_utils import CompositeMetaClass, PlaylistConverter, _, __version__
+from ..cog_utils import CompositeMetaClass, PlaylistConverter, __version__
 
 log = logging.getLogger("red.cogs.Audio.cog.Commands.audioset")
 
+_ = Translator("Audio", Path(__file__))
+
 
 class AudioSetCommands(MixinMeta, metaclass=CompositeMetaClass):
     @commands.group(name="audioset")
@@ -888,6 +895,21 @@ class AudioSetCommands(MixinMeta, metaclass=CompositeMetaClass):
             ),
         )
 
+    @command_audioset.command(name="autodeafen")
+    @commands.guild_only()
+    @commands.mod_or_permissions(manage_guild=True)
+    async def command_audioset_auto_deafen(self, ctx: commands.Context):
+        """Toggle whether the bot will be auto deafened upon joining the voice channel."""
+        auto_deafen = await self.config.guild(ctx.guild).auto_deafen()
+        await self.config.guild(ctx.guild).auto_deafen.set(not auto_deafen)
+        await self.send_embed_msg(
+            ctx,
+            title=_("Setting Changed"),
+            description=_("Auto Deafen: {true_or_false}.").format(
+                true_or_false=_("Enabled") if not auto_deafen else _("Disabled")
+            ),
+        )
+
     @command_audioset.command(name="restrict")
     @commands.is_owner()
     @commands.guild_only()
@@ -951,6 +973,9 @@ class AudioSetCommands(MixinMeta, metaclass=CompositeMetaClass):
         bumpped_shuffle = _("Enabled") if data["shuffle_bumped"] else _("Disabled")
         song_notify = _("Enabled") if data["notify"] else _("Disabled")
         song_status = _("Enabled") if global_data["status"] else _("Disabled")
+        persist_queue = _("Enabled") if data["persist_queue"] else _("Disabled")
+        auto_deafen = _("Enabled") if data["auto_deafen"] else _("Disabled")
+
         countrycode = data["country_code"]
 
         spotify_cache = CacheLevel.set_spotify()
@@ -992,7 +1017,9 @@ class AudioSetCommands(MixinMeta, metaclass=CompositeMetaClass):
             "Shuffle bumped:   [{bumpped_shuffle}]\n"
             "Song notify msgs: [{notify}]\n"
             "Songs as status:  [{status}]\n"
+            "Persist queue:    [{persist_queue}]\n"
             "Spotify search:   [{countrycode}]\n"
+            "Auto-Deafen:      [{auto_deafen}]\n"
         ).format(
             countrycode=countrycode,
             repeat=song_repeat,
@@ -1000,6 +1027,8 @@ class AudioSetCommands(MixinMeta, metaclass=CompositeMetaClass):
             notify=song_notify,
             status=song_status,
             bumpped_shuffle=bumpped_shuffle,
+            persist_queue=persist_queue,
+            auto_deafen=auto_deafen,
         )
         if thumbnail:
             msg += _("Thumbnails:       [{0}]\n").format(
@@ -1050,16 +1079,22 @@ class AudioSetCommands(MixinMeta, metaclass=CompositeMetaClass):
                 + _("Local Spotify cache:    [{spotify_status}]\n")
                 + _("Local Youtube cache:    [{youtube_status}]\n")
                 + _("Local Lavalink cache:   [{lavalink_status}]\n")
-                # + _("Global cache status:    [{global_cache}]\n")
-                # + _("Global timeout:         [{num_seconds}]\n")
+                + _("Global cache status:    [{global_cache}]\n")
+                + _("Global timeout:         [{num_seconds}]\n")
             ).format(
                 max_age=str(await self.config.cache_age()) + " " + _("days"),
                 spotify_status=_("Enabled") if has_spotify_cache else _("Disabled"),
                 youtube_status=_("Enabled") if has_youtube_cache else _("Disabled"),
                 lavalink_status=_("Enabled") if has_lavalink_cache else _("Disabled"),
-                # global_cache=_("Enabled") if global_data["global_db_enabled"] else _("Disabled"),
-                # num_seconds=self.get_time_string(global_data["global_db_get_timeout"]),
+                global_cache=_("Enabled") if global_data["global_db_enabled"] else _("Disabled"),
+                num_seconds=self.get_time_string(global_data["global_db_get_timeout"]),
             )
+        msg += (
+            "\n---"
+            + _("User Settings")
+            + "---        \n"
+            + _("Spotify search:   [{country_code}]\n")
+        ).format(country_code=await self.config.user(ctx.author).country_code())
 
         msg += (
             "\n---"
@@ -1075,25 +1110,68 @@ class AudioSetCommands(MixinMeta, metaclass=CompositeMetaClass):
             if global_data["use_external_lavalink"]
             else _("Disabled"),
         )
-        if not global_data["use_external_lavalink"] and self.player_manager.ll_build:
+        if is_owner and not global_data["use_external_lavalink"] and self.player_manager.ll_build:
             msg += _(
                 "Lavalink build:         [{llbuild}]\n"
                 "Lavalink branch:        [{llbranch}]\n"
                 "Release date:           [{build_time}]\n"
                 "Lavaplayer version:     [{lavaplayer}]\n"
                 "Java version:           [{jvm}]\n"
+                "Java Executable:        [{jv_exec}]\n"
             ).format(
                 build_time=self.player_manager.build_time,
                 llbuild=self.player_manager.ll_build,
                 llbranch=self.player_manager.ll_branch,
                 lavaplayer=self.player_manager.lavaplayer,
                 jvm=self.player_manager.jvm,
+                jv_exec=self.player_manager.path,
             )
         if is_owner:
             msg += _("Localtracks path:       [{localpath}]\n").format(**global_data)
 
         await self.send_embed_msg(ctx, description=box(msg, lang="ini"))
 
+    @command_audioset.command(name="logs")
+    @commands.is_owner()
+    @has_internal_server()
+    @commands.guild_only()
+    async def command_audioset_logs(self, ctx: commands.Context):
+        """Sends the Lavalink server logs to your DMs."""
+        datapath = cog_data_path(raw_name="Audio")
+        logs = datapath / "logs" / "spring.log"
+        zip_name = None
+        try:
+            try:
+                if not (logs.exists() and logs.is_file()):
+                    return await ctx.send(_("No logs found in your data folder."))
+            except OSError:
+                return await ctx.send(_("No logs found in your data folder."))
+
+            def check(path):
+                return os.path.getsize(str(path)) > (8388608 - 1000)
+
+            if check(logs):
+                zip_name = logs.with_suffix(".tar.gz")
+                zip_name.unlink(missing_ok=True)
+                with tarfile.open(zip_name, "w:gz") as tar:
+                    tar.add(str(logs), arcname="spring.log", recursive=False)
+                if check(zip_name):
+                    await ctx.send(
+                        _("Logs are too large, you can find them in {path}").format(
+                            path=zip_name.absolute()
+                        )
+                    )
+                    zip_name = None
+                else:
+                    await ctx.author.send(file=discord.File(str(zip_name)))
+            else:
+                await ctx.author.send(file=discord.File(str(logs)))
+        except discord.HTTPException:
+            await ctx.send(_("I need to be able to DM you to send you the logs."))
+        finally:
+            if zip_name is not None:
+                zip_name.unlink(missing_ok=True)
+
     @command_audioset.command(name="status")
     @commands.is_owner()
     @commands.guild_only()
@@ -1212,6 +1290,28 @@ class AudioSetCommands(MixinMeta, metaclass=CompositeMetaClass):
 
         await self.config.guild(ctx.guild).country_code.set(country)
 
+    @command_audioset.command(name="mycountrycode")
+    @commands.guild_only()
+    async def command_audioset_countrycode_user(self, ctx: commands.Context, country: str):
+        """Set the country code for Spotify searches."""
+        if len(country) != 2:
+            return await self.send_embed_msg(
+                ctx,
+                title=_("Invalid Country Code"),
+                description=_(
+                    "Please use an official [ISO 3166-1 alpha-2]"
+                    "(https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) code."
+                ),
+            )
+        country = country.upper()
+        await self.send_embed_msg(
+            ctx,
+            title=_("Setting Changed"),
+            description=_("Country Code set to {country}.").format(country=country),
+        )
+
+        await self.config.user(ctx.author).country_code.set(country)
+
     @command_audioset.command(name="cache")
     @commands.is_owner()
     async def command_audioset_cache(self, ctx: commands.Context, *, level: int = None):
@@ -1315,3 +1415,71 @@ class AudioSetCommands(MixinMeta, metaclass=CompositeMetaClass):
         msg += _("I've set the cache age to {age} days").format(age=age)
         await self.config.cache_age.set(age)
         await self.send_embed_msg(ctx, title=_("Setting Changed"), description=msg)
+
+    @commands.is_owner()
+    @command_audioset.group(name="globalapi")
+    async def command_audioset_audiodb(self, ctx: commands.Context):
+        """Change globalapi settings."""
+
+    @command_audioset_audiodb.command(name="toggle")
+    async def command_audioset_audiodb_toggle(self, ctx: commands.Context):
+        """Toggle the server settings.
+
+        Default is OFF
+        """
+        state = await self.config.global_db_enabled()
+        await self.config.global_db_enabled.set(not state)
+        if not state:  # Ensure a call is made if the API is enabled to update user perms
+            self.global_api_user = await self.api_interface.global_cache_api.get_perms()
+        await ctx.send(
+            _("Global DB is {status}").format(status=_("enabled") if not state else _("disabled"))
+        )
+
+    @command_audioset_audiodb.command(name="timeout")
+    async def command_audioset_audiodb_timeout(
+        self, ctx: commands.Context, timeout: Union[float, int]
+    ):
+        """Set GET request timeout.
+
+        Example: 0.1 = 100ms 1 = 1 second
+        """
+
+        await self.config.global_db_get_timeout.set(timeout)
+        await ctx.send(_("Request timeout set to {time} second(s)").format(time=timeout))
+
+    @command_audioset.command(name="persistqueue")
+    @commands.admin()
+    async def command_audioset_persist_queue(self, ctx: commands.Context):
+        """Toggle persistent queues.
+
+        Persistent queues allows the current queue to be restored when the queue closes.
+        """
+        persist_cache = self._persist_queue_cache.setdefault(
+            ctx.guild.id, await self.config.guild(ctx.guild).persist_queue()
+        )
+        await self.config.guild(ctx.guild).persist_queue.set(not persist_cache)
+        self._persist_queue_cache[ctx.guild.id] = not persist_cache
+        await self.send_embed_msg(
+            ctx,
+            title=_("Setting Changed"),
+            description=_("Persisting queues: {true_or_false}.").format(
+                true_or_false=_("Enabled") if not persist_cache else _("Disabled")
+            ),
+        )
+
+    @command_audioset.command(name="restart")
+    @commands.is_owner()
+    async def command_audioset_restart(self, ctx: commands.Context):
+        """Restarts the lavalink connection."""
+        async with ctx.typing():
+            await lavalink.close()
+            if self.player_manager is not None:
+                await self.player_manager.shutdown()
+
+            self.lavalink_restart_connect()
+
+            await self.send_embed_msg(
+                ctx,
+                title=_("Restarting Lavalink"),
+                description=_("It can take a couple of minutes for Lavalink to fully start up."),
+            )
