@@ -58,6 +58,7 @@ class Streams(commands.Cog):
         "live_message_mention": False,
         "live_message_nomention": False,
         "ignore_reruns": False,
+        "ignore_schedule": False,
     }
 
     role_defaults = {"mention": False}
@@ -223,9 +224,9 @@ class Streams(commands.Cog):
         apikey = await self.bot.get_shared_api_tokens("youtube")
         is_name = self.check_name_or_id(channel_id_or_name)
         if is_name:
-            stream = YoutubeStream(name=channel_id_or_name, token=apikey)
+            stream = YoutubeStream(name=channel_id_or_name, token=apikey, config=self.config)
         else:
-            stream = YoutubeStream(id=channel_id_or_name, token=apikey)
+            stream = YoutubeStream(id=channel_id_or_name, token=apikey, config=self.config)
         await self.check_online(ctx, stream)
 
     @commands.command()
@@ -298,12 +299,9 @@ class Streams(commands.Cog):
         pass
 
     @streamalert.group(name="twitch", invoke_without_command=True)
-    async def _twitch(self, ctx: commands.Context, channel_name: str = None):
+    async def _twitch(self, ctx: commands.Context, channel_name: str):
         """Manage Twitch stream notifications."""
-        if channel_name is not None:
-            await ctx.invoke(self.twitch_alert_channel, channel_name)
-        else:
-            await ctx.send_help()
+        await ctx.invoke(self.twitch_alert_channel, channel_name)
 
     @_twitch.command(name="channel")
     async def twitch_alert_channel(self, ctx: commands.Context, channel_name: str):
@@ -398,7 +396,7 @@ class Streams(commands.Cog):
             is_yt = _class.__name__ == "YoutubeStream"
             is_twitch = _class.__name__ == "TwitchStream"
             if is_yt and not self.check_name_or_id(channel_name):
-                stream = _class(id=channel_name, token=token)
+                stream = _class(id=channel_name, token=token, config=self.config)
             elif is_twitch:
                 await self.maybe_renew_twitch_bearer_token()
                 stream = _class(
@@ -407,7 +405,10 @@ class Streams(commands.Cog):
                     bearer=self.ttv_bearer_cache.get("access_token", None),
                 )
             else:
-                stream = _class(name=channel_name, token=token)
+                if is_yt:
+                    stream = _class(name=channel_name, token=token, config=self.config)
+                else:
+                    stream = _class(name=channel_name, token=token)
             try:
                 exists = await self.check_exists(stream)
             except InvalidTwitchCredentials:
@@ -519,12 +520,12 @@ class Streams(commands.Cog):
     @streamset.group()
     @commands.guild_only()
     async def message(self, ctx: commands.Context):
-        """Manage custom message for stream alerts."""
+        """Manage custom messages for stream alerts."""
         pass
 
     @message.command(name="mention")
     @commands.guild_only()
-    async def with_mention(self, ctx: commands.Context, *, message: str = None):
+    async def with_mention(self, ctx: commands.Context, *, message: str):
         """Set stream alert message when mentions are enabled.
 
         Use `{mention}` in the message to insert the selected mentions.
@@ -532,28 +533,22 @@ class Streams(commands.Cog):
 
         For example: `[p]streamset message mention {mention}, {stream} is live!`
         """
-        if message is not None:
-            guild = ctx.guild
-            await self.config.guild(guild).live_message_mention.set(message)
-            await ctx.send(_("Stream alert message set!"))
-        else:
-            await ctx.send_help()
+        guild = ctx.guild
+        await self.config.guild(guild).live_message_mention.set(message)
+        await ctx.send(_("Stream alert message set!"))
 
     @message.command(name="nomention")
     @commands.guild_only()
-    async def without_mention(self, ctx: commands.Context, *, message: str = None):
+    async def without_mention(self, ctx: commands.Context, *, message: str):
         """Set stream alert message when mentions are disabled.
 
         Use `{stream}` in the message to insert the channel or user name.
 
         For example: `[p]streamset message nomention {stream} is live!`
         """
-        if message is not None:
-            guild = ctx.guild
-            await self.config.guild(guild).live_message_nomention.set(message)
-            await ctx.send(_("Stream alert message set!"))
-        else:
-            await ctx.send_help()
+        guild = ctx.guild
+        await self.config.guild(guild).live_message_nomention.set(message)
+        await ctx.send(_("Stream alert message set!"))
 
     @message.command(name="clear")
     @commands.guild_only()
@@ -645,6 +640,19 @@ class Streams(commands.Cog):
             await self.config.guild(guild).ignore_reruns.set(True)
             await ctx.send(_("Streams of type 'rerun' will no longer send an alert."))
 
+    @streamset.command(name="ignoreschedule")
+    @commands.guild_only()
+    async def ignore_schedule(self, ctx: commands.Context):
+        """Toggle excluding YouTube streams schedules from alerts."""
+        guild = ctx.guild
+        current_setting = await self.config.guild(guild).ignore_schedule()
+        if current_setting:
+            await self.config.guild(guild).ignore_schedule.set(False)
+            await ctx.send(_("Streams schedules will be included in alerts."))
+        else:
+            await self.config.guild(guild).ignore_schedule.set(True)
+            await ctx.send(_("Streams schedules will no longer send an alert."))
+
     async def add_or_remove(self, ctx: commands.Context, stream):
         if ctx.channel.id not in stream.channels:
             stream.channels.append(ctx.channel.id)
@@ -705,25 +713,40 @@ class Streams(commands.Cog):
                 pass
             await asyncio.sleep(await self.config.refresh_timer())
 
+    async def _send_stream_alert(
+        self, stream, channel: discord.TextChannel, embed: discord.Embed, content: str = None
+    ):
+        m = await channel.send(
+            content,
+            embed=embed,
+            allowed_mentions=discord.AllowedMentions(roles=True, everyone=True),
+        )
+        stream._messages_cache.append(m)
+
     async def check_streams(self):
         for stream in self.streams:
-            with contextlib.suppress(Exception):
+            try:
                 try:
                     if stream.__class__.__name__ == "TwitchStream":
                         await self.maybe_renew_twitch_bearer_token()
                         embed, is_rerun = await stream.is_online()
+
+                    elif stream.__class__.__name__ == "YoutubeStream":
+                        embed, is_schedule = await stream.is_online()
+
                     else:
                         embed = await stream.is_online()
                         is_rerun = False
+                        is_schedule = False
                 except OfflineStream:
                     if not stream._messages_cache:
                         continue
                     for message in stream._messages_cache:
-                        with contextlib.suppress(Exception):
-                            if await self.bot.cog_disabled_in_guild(self, message.guild):
-                                continue
-                            autodelete = await self.config.guild(message.guild).autodelete()
-                            if autodelete:
+                        if await self.bot.cog_disabled_in_guild(self, message.guild):
+                            continue
+                        autodelete = await self.config.guild(message.guild).autodelete()
+                        if autodelete:
+                            with contextlib.suppress(discord.NotFound):
                                 await message.delete()
                     stream._messages_cache.clear()
                     await self.save_streams()
@@ -739,7 +762,14 @@ class Streams(commands.Cog):
                         ignore_reruns = await self.config.guild(channel.guild).ignore_reruns()
                         if ignore_reruns and is_rerun:
                             continue
-
+                        ignore_schedules = await self.config.guild(channel.guild).ignore_schedule()
+                        if ignore_schedules and is_schedule:
+                            continue
+                        if is_schedule:
+                            # skip messages and mentions
+                            await self._send_stream_alert(stream, channel, embed)
+                            await self.save_streams()
+                            continue
                         await set_contextual_locales_from_guild(self.bot, channel.guild)
 
                         mention_str, edited_roles = await self._get_mention_str(
@@ -780,17 +810,13 @@ class Streams(commands.Cog):
                                         str(stream.name), mass_mentions=True, formatting=True
                                     )
                                 )
-
-                        m = await channel.send(
-                            content,
-                            embed=embed,
-                            allowed_mentions=discord.AllowedMentions(roles=True, everyone=True),
-                        )
-                        stream._messages_cache.append(m)
+                        await self._send_stream_alert(stream, channel, embed, content)
                         if edited_roles:
                             for role in edited_roles:
                                 await role.edit(mentionable=False)
                         await self.save_streams()
+            except Exception as e:
+                log.error("An error has occured with Streams. Please report it.", exc_info=e)
 
     async def _get_mention_str(
         self, guild: discord.Guild, channel: discord.TextChannel
@@ -855,6 +881,8 @@ class Streams(commands.Cog):
                     raw_stream["token"] = token.get("client_id")
                     raw_stream["bearer"] = self.ttv_bearer_cache.get("access_token", None)
                 else:
+                    if _class.__name__ == "YoutubeStream":
+                        raw_stream["config"] = self.config
                     raw_stream["token"] = token
             streams.append(_class(**raw_stream))
 
